.. _fasta-utils:

fasta-utils - Fasta Utilities
=============================

Overview
--------

.. automodule:: mgkit.workflow.fasta_utils


Options
-------

.. click:: mgkit.workflow.fasta_utils:main
   :prog: fasta-utils
   :show-nested:
